@@ -410,7 +410,7 @@ drapery <- function(x, type = "zvalue", layout = "grayscale",
   ##
   if (missing(xlab)) {
     xlab <- ""
-    xlab <- xlab(x$sm, backtransf = backtransf)
+    xlab <- xlab_meta(x$sm, backtransf = backtransf)
   }
   else
     chkchar(xlab, length = 1)
