@@ -579,9 +579,9 @@ draw.lines <- function(x, column,
                        ymin.common, ymin.random, ymin.ref, ymax,
                        lwd, lty.common, lty.random, col.common, col.random,
                        xmin, xmax,
-                       lower.equi, upper.equi,
-                       lty.equi, col.equi,
-                       fill.lower.equi, fill.upper.equi,
+                       cid.below.null, cid.above.null,
+                       lty.cid, col.cid,
+                       fill.cid.below.null, fill.cid.above.null,
                        fill,
                        col.line) {
   ##
@@ -604,94 +604,94 @@ draw.lines <- function(x, column,
                           "lines"),
                  gp = gpar(col = fill, fill = fill))
   ##
-  ## Add equivalence region(s)
+  ## Add equivalence region
   ##
-  if (is.na(ref) & any(!is.na(lower.equi)) & any(!is.na(upper.equi)))
-    ref.equi <- min(lower.equi, na.rm = TRUE) +
-      0.5 * (max(upper.equi, na.rm = TRUE) - min(lower.equi, na.rm = TRUE))
+  if (is.na(ref) & any(!is.na(cid.below.null)) & any(!is.na(cid.above.null)))
+    ref.equi <- min(cid.below.null, na.rm = TRUE) +
+      0.5 * (max(cid.above.null, na.rm = TRUE) - min(cid.below.null, na.rm = TRUE))
   else
     ref.equi <- ref
   ##
   if (!is.na(ref.equi) && (xmin <= ref.equi & ref.equi <= xmax) &&
-      any(!is.na(lower.equi))) {
+      any(!is.na(cid.below.null))) {
     ##
-    n.lower.equi <- sum(!is.na(lower.equi))
-    n.fill.lower.equi <- length(fill.lower.equi)
+    n.cid.below.null <- sum(!is.na(cid.below.null))
+    n.fill.cid.below.null <- length(fill.cid.below.null)
     ##
-    if (n.lower.equi < n.fill.lower.equi) {
+    if (n.cid.below.null < n.fill.cid.below.null) {
       firstline <- FALSE
-      lower.equi <- c(xmin, lower.equi, ref.equi)
+      cid.below.null <- c(xmin, cid.below.null, ref.equi)
     }
     else {
       firstline <- TRUE
-      lower.equi <- c(lower.equi, ref.equi)
+      cid.below.null <- c(cid.below.null, ref.equi)
     }
     ##
-    n.lo <- length(lower.equi[-1])
+    n.lo <- length(cid.below.null[-1])
     ##
     for (i in seq_len(n.lo)) {
-      if (!is.na(lower.equi[i]) && !is.na(lower.equi[i + 1]) &&
-          ((xmin <= lower.equi[i] & lower.equi[i] <= lower.equi[i + 1]) &
-           (lower.equi[i + 1] <= xmax))) {
+      if (!is.na(cid.below.null[i]) && !is.na(cid.below.null[i + 1]) &&
+          ((xmin <= cid.below.null[i] & cid.below.null[i] <= cid.below.null[i + 1]) &
+           (cid.below.null[i + 1] <= xmax))) {
         ##
-        grid.polygon(x = unit(c(lower.equi[i], lower.equi[i + 1],
-                                lower.equi[i + 1], lower.equi[i]), "native"),
+        grid.polygon(x = unit(c(cid.below.null[i], cid.below.null[i + 1],
+                                cid.below.null[i + 1], cid.below.null[i]), "native"),
                      y = unit(c(ymin.ref, ymin.ref, ymax, ymax),
                               "lines"),
                      gp = gpar(lwd = lwd, col = "transparent",
-                               fill = fill.lower.equi[i]))
+                               fill = fill.cid.below.null[i]))
       }
     }
     ##
     for (i in seq_len(n.lo)) {
       if (!(i == 1 & !firstline) &
-          !is.na(lower.equi[i]) && !is.na(lower.equi[i + 1]) &&
-          ((xmin <= lower.equi[i] & lower.equi[i] <= lower.equi[i + 1]) &
-           (lower.equi[i + 1] <= xmax)))
-        grid.lines(x = unit(lower.equi[i], "native"),
+          !is.na(cid.below.null[i]) && !is.na(cid.below.null[i + 1]) &&
+          ((xmin <= cid.below.null[i] & cid.below.null[i] <= cid.below.null[i + 1]) &
+           (cid.below.null[i + 1] <= xmax)))
+        grid.lines(x = unit(cid.below.null[i], "native"),
                    y = unit(c(ymin.ref, ymax), "lines"),
-                   gp = gpar(lwd = lwd, col = col.equi, lty = lty.equi))
+                   gp = gpar(lwd = lwd, col = col.cid, lty = lty.cid))
     }
   }
   ##
   if (!is.na(ref.equi) && (xmin <= ref.equi & ref.equi <= xmax) &&
-      any(!is.na(upper.equi))) {
+      any(!is.na(cid.above.null))) {
     ##
-    n.upper.equi <- sum(!is.na(upper.equi))
-    n.fill.upper.equi <- length(fill.upper.equi)
+    n.cid.above.null <- sum(!is.na(cid.above.null))
+    n.fill.cid.above.null <- length(fill.cid.above.null)
     ##
-    if (n.upper.equi < n.fill.upper.equi) {
+    if (n.cid.above.null < n.fill.cid.above.null) {
       lastline <- FALSE
-      upper.equi <- c(ref.equi, upper.equi, xmax)
+      cid.above.null <- c(ref.equi, cid.above.null, xmax)
     }
     else {
       lastline <- TRUE
-      upper.equi <- c(ref.equi, upper.equi)
+      cid.above.null <- c(ref.equi, cid.above.null)
     }
     ##
-    n.up <- length(upper.equi[-1])
+    n.up <- length(cid.above.null[-1])
     ##
     for (i in seq_len(n.up)) {
-      if (!is.na(upper.equi[i]) && !is.na(upper.equi[i + 1]) &&
-          ((xmin <= upper.equi[i] & upper.equi[i] <= upper.equi[i + 1]) &
-           (upper.equi[i + 1] <= xmax))) {
+      if (!is.na(cid.above.null[i]) && !is.na(cid.above.null[i + 1]) &&
+          ((xmin <= cid.above.null[i] & cid.above.null[i] <= cid.above.null[i + 1]) &
+           (cid.above.null[i + 1] <= xmax))) {
         ##
-        grid.polygon(x = unit(c(upper.equi[i], upper.equi[i + 1],
-                                upper.equi[i + 1], upper.equi[i]), "native"),
+        grid.polygon(x = unit(c(cid.above.null[i], cid.above.null[i + 1],
+                                cid.above.null[i + 1], cid.above.null[i]), "native"),
                      y = unit(c(ymin.ref, ymin.ref, ymax, ymax),
                               "lines"),
                      gp = gpar(lwd = lwd, col = "transparent",
-                               fill = fill.upper.equi[i]))
+                               fill = fill.cid.above.null[i]))
       }
     }
     ##
     for (i in seq_len(n.up)) {
       if ((i != n.up | (i == n.up & lastline)) &
-          !is.na(upper.equi[i + 1]) &&
-          (xmin <= upper.equi[i + 1] & upper.equi[i + 1] <= xmax))
-          grid.lines(x = unit(upper.equi[i + 1], "native"),
+          !is.na(cid.above.null[i + 1]) &&
+          (xmin <= cid.above.null[i + 1] & cid.above.null[i + 1] <= xmax))
+          grid.lines(x = unit(cid.above.null[i + 1], "native"),
                      y = unit(c(ymin.ref, ymax), "lines"),
-                     gp = gpar(lwd = lwd, col = col.equi, lty = lty.equi))
+                     gp = gpar(lwd = lwd, col = col.cid, lty = lty.cid))
     }
   }
   ##
@@ -1199,3 +1199,129 @@ show_subgroup_results <- function(x, n, lower, upper) {
     return(x)
   }
 }
+
+newCol <- function(varname, label,
+                   rob, data1, data2, datap,
+                   n.com, n.ran, n.prd,
+                   notavail, lab.NA, big.mark,
+                   zero.pval, JAMA.pval, scientific.pval,
+                   digits, digits.pval, digits.tau2, digits.tau, digits.I2,
+                   sel.prd,
+                   n.com.w = 0, n.ran.w = 0, n.prd.w = 0, n.stat.w = 0) {
+  
+  by <- sum(c(n.com.w, n.ran.w, n.prd.w, n.stat.w) > 0)
+  #
+  n.subgroup <- n.com.w + n.ran.w + n.prd.w + n.stat.w
+  #
+  if (length(rob[[varname]]) != 0)
+    fvar <- rob[[varname]]
+  else if (length(data1[[varname]]) != 0)
+    fvar <- data1[[varname]]
+  else if (length(data2[[varname]]) != 0)
+    fvar <- data2[[varname]]
+  else
+    stop("Variable '", varname,
+         "' not available in meta-analysis object.",
+         call. = FALSE)
+  #
+  if (isCol(datap, varname)) {
+    if (nrow(datap) == 1) {
+      fvar <- c(rep(datap[[varname]], n.com),
+                rep(datap[[varname]], n.ran),
+                rep(NA, n.prd),
+                if (by) rep(NA, n.subgroup) else NULL,
+                fvar)
+    }
+    else if (nrow(datap) == n.com + n.ran)
+      fvar <- c(datap[[varname]],
+                rep(NA, n.prd),
+                if (by) rep(NA, n.subgroup) else NULL,
+                fvar)
+    else if (nrow(datap) == n.com + n.ran + n.com.w + n.ran.w)
+      fvar <- c(datap[[varname]][seq_len(n.com + n.ran)],
+                rep(NA, n.prd),
+                datap[[varname]][n.com + n.ran + seq_len(n.com.w + n.ran.w)],
+                rep(NA, n.prd.w + n.stat.w),
+                fvar)
+    else
+      stop("Wrong number of row in data set 'data.pooled' ",
+           "(must be 1",
+           if (by)", " else " or ", n.com + n.ran,,
+           if (by) " or ", n.com.w + n.ran.w, ").",
+           call. = FALSE)
+  }
+  #
+  if (!is.character(fvar)) {
+    if (is.factor(fvar))
+      fvar <- as.character(fvar)
+    else if (notavail & all(is_wholenumber(fvar), na.rm = TRUE))
+      fvar <-
+        formatN(fvar, digits = 0, text.NA = lab.NA, big.mark = big.mark)
+    else if (is.numeric(fvar)) {
+      if (varname == "pval")
+        fvar <- formatPT(fvar, digits = digits.pval,
+                          big.mark = big.mark,
+                          lab = FALSE, labval = "",
+                          zero = zero.pval, JAMA = JAMA.pval,
+                          scientific = scientific.pval,
+                          lab.NA = lab.NA)
+      else if (varname == "tau2")
+        fvar <- formatPT(fvar, digits = digits.tau2,
+                          big.mark = big.mark,
+                          lab = FALSE, labval = "",
+                          lab.NA = lab.NA)
+      else if (varname == "tau")
+        fvar <- formatPT(fvar, digits = digits.tau,
+                          big.mark = big.mark,
+                          lab = FALSE, labval = "",
+                          lab.NA = lab.NA)
+      else if (varname == "I2") {
+        sel.r <- !is.na(fvar)
+        fvar[sel.r] <-
+          paste0(formatN(100 * fvar[sel.r], digits.I2), "%")
+        fvar[!sel.r] <- lab.NA
+      }
+      else
+        fvar <-
+          formatN(fvar, digits = digits, text.NA = lab.NA, big.mark = big.mark)
+    }
+  }
+  #
+  fvar <- ifelse(is.na(fvar), "", fvar)
+  #
+  # Print nothing for lines with prediction interval
+  #
+  if (isCol(datap, varname))
+    fvar[sel.prd] <- ""
+  else
+    fvar <- c(rep("", n.com), rep("", n.ran), rep("", n.prd),
+              if (by) rep("", n.subgroup),
+              fvar)
+  #
+  # Print nothing for lines for subgroups
+  #
+  if (by) {
+    is_NA <- fvar == lab.NA
+    is_w <- rep(TRUE, length(fvar))
+    is_w[seq_len(n.com + n.ran + n.prd)] <- FALSE
+    #
+    fvar[is_NA & is_w] <- ""
+  }
+  #
+  # Check for "\n" in label of new column
+  #
+  clines <- twolines(label, varname)
+  #
+  if (clines$newline) {
+    label <- clines$bottom
+    longer <- clines$longer
+  }
+  else
+    label <- longer <- label
+  #
+  res <- list(format_var = fvar, colname = paste0("col.", varname),
+              label = label, longer = longer,
+              rob = length(rob[[varname]]) != 0)
+  #
+  res
+}
