@@ -46,7 +46,54 @@ gm <- function(x, digits = 4, debug = FALSE) {
     ##
     return(res)
   }
-  else if (inherits(x, c("metacum", "metainf"))) {
+  #
+  if (inherits(x, c("metacum", "metainf"))) {
+    if (x$pooled == "random") {
+      df.randoms <-
+        replaceNULL(sort(unique(c(x$df.random, x$df.random.pooled))))
+      #
+      df.randoms <- df.randoms[is.finite(df.randoms)]
+      #
+      if (length(df.randoms) == 0)
+        label.df.random <- ""
+      else if (length(df.randoms) == 1)
+        label.df.random <- df.randoms
+      else {
+        if (all(diff(df.randoms) == 1) & length(df.randoms) > 5)
+          label.df.random <-
+            paste0("{", min(df.randoms), ", ..., ", max(df.randoms), "}")
+        else
+          label.df.random <-
+            paste0("{", paste(df.randoms, collapse = ", "), "}")
+      }
+      #
+      if (x$prediction) {
+        df.predicts <-
+          replaceNULL(sort(unique(c(x$df.predict, x$df.predict.pooled))))
+        #
+        df.predicts <- df.predicts[is.finite(df.predicts)]
+        #
+        if (length(df.predicts) == 0)
+          label.df.predict <- ""
+        else if (length(df.predicts) == 1)
+          label.df.predict <- df.predicts
+        else {
+          if (all(diff(df.predicts) == 1))
+            label.df.predict <-
+              paste0("{", min(df.predicts), ", ..., ", max(df.predicts), "}")
+          else
+            label.df.predict <-
+              paste0("{", paste(df.predicts, collapse = ", "), "}")
+        }
+      }
+      else
+        label.df.predict <- ""
+    }
+    else {
+      label.df.random <- ""
+      label.df.predict <- ""
+    }
+    #
     res <-
       with(
         x,
@@ -54,35 +101,37 @@ gm <- function(x, digits = 4, debug = FALSE) {
           meth =
             func(
               model = pooled,
-              method =
-                if (pooled == "common") method
-                else method.random,
-              three.level,
-              k, k.all, k.MH = replaceNULL(x$k.MH),
-              k.study, k.TE,
-              k0 = replaceNULL(x$k0),
-              method.tau,
-              method.tau.ci =
-                if (length(method.tau.ci[method.tau.ci != ""]) == 0) ""
-                else method.tau.ci[method.tau.ci != ""],
-              tau = NA, tau.preset = replaceNULL(tau.preset),
-              method.I2,
-              method.random.ci,
-              df.random = replaceNULL(df.random), adhoc.hakn.ci,
-              rho = replaceNULL(rho)),
-          pred = data.frame()
+              method = method, three.level = FALSE,
+              k = k.pooled, k.all = k.all.pooled,
+              k.MH = replaceNULL(x$k.MH.pooled),
+              k.study = k.study.pooled, k.TE = k.TE.pooled,
+              k0 = NA,
+              method.tau = method.tau,
+              method.tau.ci = replaceNULL(method.tau.ci, ""),
+              tau = round(tau.pooled, digits),
+              tau.preset = replaceNULL(tau.preset),
+              method.I2 = method.I2,
+              method.random.ci = method.random.ci,
+              df.random = label.df.random,
+              Q.Cochrane = replaceNULL(x$Q.Cochrane, FALSE),
+              adhoc.hakn.ci = adhoc.hakn.ci,
+              rho = 0),
+          pred =
+            func(
+              model = if (pooled == "random") "predict" else pooled,
+              method.predict,
+              df.predict = label.df.predict,
+              adhoc.hakn.pi)
         )
       )
-    ##
+    #
+    if (debug)
+      print(res)
+    #
     res$meth <- subset(res$meth, model %in% c("common", "random"))
-    ##
-    ## Add row with information on random effects model (to print
-    ## information on tau2)
-    ##
-    if (all(res$meth$model == "common")) {
-      res$meth <- rbind(res$meth, res$meth[nrow(res$meth), ])
-      res$meth$model[nrow(res$meth)] <- "random"
-    }
+    res$pred <- subset(res$pred, model == "predict")
+    #
+    return(res)
   }
   else {
     ##
