@@ -5,7 +5,7 @@
 #' meta-analyses with correlations; inverse variance weighting is used
 #' for pooling.
 #' 
-#' @param cor Correlation.
+#' @param cor Correlations.
 #' @param n Number of observations.
 #' @param studlab An optional vector with study labels.
 #' @param data An optional data frame containing the study
@@ -52,6 +52,7 @@
 #'   between-study variance tau-squared.
 #' @param tau.common A logical indicating whether tau-squared should
 #'   be the same across subgroups.
+#' @param detail.tau Detail on between-study variance estimate.
 #' @param method.I2 A character string indicating which method is
 #'   used to estimate the heterogeneity statistic I\eqn{^2}. Either
 #'   \code{"Q"} or \code{"tau2"}, can be abbreviated
@@ -133,15 +134,17 @@
 #' @param \dots Additional arguments (to catch deprecated arguments).
 #' 
 #' @details
-#' Common effect and random effects meta-analysis of correlations
-#' based either on Fisher's z transformation of correlations (\code{sm
-#' = "ZCOR"}) or direct combination of (untransformed) correlations
-#' (\code{sm = "COR"}) (see Cooper et al., 2009, p264-5 and
-#' p273-4). Only few statisticians would advocate the use of
-#' untransformed correlations unless sample sizes are very large (see
-#' Cooper et al., 2009, p265). The artificial example given below
-#' shows that the smallest study gets the largest weight if
-#' correlations are combined directly because the correlation is
+#' This function conducts common effect and random effects meta-analysis of
+#' correlations based either on Fisher's z transformation of correlations
+#' (\code{sm = "ZCOR"}) or direct combination of (untransformed) correlations
+#' (\code{sm = "COR"}) (see Cooper et al., 2009, p264-5 and p273-4). Note, the
+#' input to argument \code{cor} is always correlations and not Fisher's z
+#' transformed correlations if \code{sm = "ZCOR"}.
+#' 
+#' Only few statisticians would advocate the use of untransformed correlations
+#' unless sample sizes are very large (see Cooper et al., 2009, p265). The
+#' artificial example given below shows that the smallest study gets the largest
+#' weight if correlations are combined directly because the correlation is
 #' closest to 1.
 #' 
 #' A three-level random effects meta-analysis model (Van den Noortgate
@@ -227,11 +230,11 @@
 #' # Print correlations (back transformed from Fisher's z
 #' # transformation)
 #' #
-#' m1
+#' summary(m1)
 #' 
 #' # Print Fisher's z transformed correlations 
 #' #
-#' print(m1, backtransf = FALSE)
+#' print(summary(m1), backtransf = FALSE)
 #' 
 #' # Forest plot with back transformed correlations
 #' #
@@ -242,7 +245,7 @@
 #' forest(m1, backtransf = FALSE)
 #' 
 #' m2 <- update(m1, sm = "cor")
-#' m2
+#' summary(m2)
 #'
 #' \dontrun{
 #' # Identical forest plots (as back transformation is the identity
@@ -277,6 +280,7 @@ metacor <- function(cor, n, studlab,
                     level.hetstat = gs("level.hetstat"),
                     tau.preset = NULL, TE.tau = NULL,
                     tau.common = gs("tau.common"),
+                    detail.tau = NULL,
                     #
                     method.I2 = gs("method.I2"),
                     #
@@ -696,6 +700,7 @@ metacor <- function(cor, n, studlab,
                tau.preset = tau.preset,
                TE.tau = TE.tau,
                tau.common = FALSE,
+               detail.tau = detail.tau,
                #
                method.I2 = method.I2,
                #
@@ -765,6 +770,8 @@ metacor <- function(cor, n, studlab,
   ##
   ## Add data
   ##
+  res$pairwise <- FALSE
+  #
   res$call <- match.call()
   ##
   if (keepdata) {
