@@ -9,8 +9,28 @@
 #'   Details), \code{"common"}, or \code{"random"}, can be abbreviated.
 #' @param sortvar An optional vector used to sort the individual
 #'   studies (must be of same length as \code{x$TE}).
+#' @param prediction A logical indicating whether to report prediction
+#'   intervals.
+#' @param overall A logical indicating whether overall results should be
+#'   reported.
+#' @param text.pooled A character string used in printouts and forest
+#'   plots to label the pooled effect estimate.
 #' @param no A numeric specifying which meta-analysis results to
 #'   consider.
+#' @param cid A numeric value or vector specifying clinically important
+#'   differences (CID) / decision thresholds used to calculate expected
+#'   proportions of clinically important benefit or harm
+#'   (see \code{\link{cidprop}}).
+#' @param cid.below.null A single numeric defining the decision threshold below
+#'   the null effect to distinguish clinically important from not important
+#'   effects (see \code{\link{cidprop}}).
+#' @param cid.above.null A single numeric defining the decision threshold above
+#'   the null effect to distinguish clinically important from not important
+#'   effects (see \code{\link{cidprop}}).
+#' @param small.values A character string specifying whether small
+#'   treatment effects indicate a beneficial (\code{"desirable"}) or
+#'   harmful (\code{"undesirable"}) effect, can be abbreviated
+#'   (see \code{\link{cidprop}}).
 #' @param \dots Additional arguments (ignored).
 #' 
 #' @details
@@ -25,25 +45,39 @@
 #' \code{x$common} is \code{FALSE}.
 #' 
 #' @return
-#' An object of class \code{"meta"} and \code{"metacum"} with
-#' corresponding generic functions (see \code{\link{meta-object}}).
+#' An object of class \code{"metacum"} with dedicated print and forest
+#' functions.
 #' 
-#' The following list elements have a different meaning:
-#' \item{TE, seTE}{Estimated treatment effect and standard error of
-#'   pooled estimate in cumulative meta-analyses.}
-#' \item{lower, upper}{Lower and upper confidence interval limits.}
-#' \item{statistic}{Statistic for test of overall effect.}
-#' \item{pval}{P-value for test of overall effect.}
-#' \item{studlab}{Study label describing addition of studies.}
-#' \item{w}{Sum of weights from common effect or random effects model.}
-#' \item{TE.common, seTE.common}{Value is \code{NA}.}
-#' \item{TE.random, seTE.random}{Value is \code{NA}.}
-#' \item{Q}{Value is \code{NA}.}
+#' The following list elements provide results from meta-analyses, each
+#' adding one study at a time (see \code{\link{meta-object}} for more
+#' information on these list elements):
+#' \tabular{l}{
+#' \cr
+#' studlab, TE, seTE, df.random, lower, upper, statistic, pval, \cr
+#' lower.predict, upper.predict, df.predict, w (sum of weights), \cr
+#' tau2, se.tau2, lower.tau2, upper.tau2, tau, lower.tau, upper.tau, \cr
+#' I2, lower.I2, upper.I2, Rb, n.harmonic.mean, t.harmonic.mean, \cr
+#' k, k.study, k.all, k.TE, k.MH.
+#' }
+#' 
+#' The following list elements contain results of the original meta-analysis:
+#' \tabular{l}{
+#' \cr
+#' TE.pooled, seTE.pooled, df.random.pooled, \cr
+#' lower.pooled, upper.pooled, statistic.pooled, pval.pooled, \cr
+#' lower.predict.pooled, upper.predict.pooled, \cr
+#' df.predict.pooled, w.pooled, \cr
+#' tau2.pooled, se.tau2.pooled, lower.tau2.pooled, upper.tau2.pooled, \cr
+#' tau.pooled, lower.tau.pooled, upper.tau.pooled, \cr
+#' I2.pooled, lower.I2.pooled, upper.I2.pooled, Rb.pooled, \cr
+#' n.harmonic.mean.pooled, t.harmonic.mean.pooled, \cr
+#' k.pooled, k.study.pooled, k.all.pooled, k.TE.pooled, k.MH.pooled.
+#' }
 #' 
 #' @author Guido Schwarzer \email{guido.schwarzer@@uniklinik-freiburg.de}
 #' 
-#' @seealso \code{\link{metabin}}, \code{\link{metacont}},
-#'   \code{\link{print.meta}}
+#' @seealso \code{\link{forest.metacum}}, \code{\link{print.metacum}},
+#'   \code{\link{cidprop}}
 #' 
 #' @references
 #' Cooper H & Hedges LV (1994):
@@ -76,20 +110,30 @@
 #' @method metacum meta
 #' @export
 
-
-metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
-  
+metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
+                         text.pooled, no = 1,
+                         cid = NULL,
+                         cid.below.null = NULL, cid.above.null = NULL,
+                         small.values = "desirable",
+                         ...) {
   
   ##
   ##
   ## (1) Check for meta object and upgrade older meta objects
   ##
   ##
+  
   chkclass(x, "meta")
-  chksuitable(x, "Cumulative meta-analysis", c("metamerge", "netpairwise"))
-  ##
+  chksuitable(x, "Cumulative meta-analysis",
+              c("trimfill", "metamerge", "netpairwise"))
+  #
   x <- updateversion(x)
-  ##
+  #
+  if (!is.null(x$three.level) && x$three.level)
+    stop("Cumulative meta-analysis not implemented for a ",
+         "multi-level meta-analysis.",
+         call. = FALSE)
+  #
   k.all <- length(x$TE)
   if (k.all < 2) {
     warning("Nothing calculated (minimum number of studies: 2).")
@@ -102,6 +146,7 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
   ## (2) Check other arguments
   ##
   ##
+  
   if (!missing(pooled)) {
     pooled <- setchar(pooled, c("common", "random", "fixed"))
     pooled[pooled == "fixed"] <- "common"
@@ -111,7 +156,17 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
       pooled <- "random"
     else
       pooled <- "common"
-  ##
+  #
+  if (missing(prediction))
+    prediction <- pooled == "random" & x$prediction
+  else
+    chklogical(prediction)
+  #
+  chklogical(overall)
+  #
+  tdist_random <- pooled == "random" & x$method.random.ci %in% c("HK", "KR")
+  tdist_predict <- !(x$method.predict %in% c("S", ""))
+  #
   mc <- match.call()
   error <-
     try(sortvar <-
@@ -127,7 +182,24 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
     stop("Number of studies in object 'x' and argument 'sortvar' ",
          "have different length.")
   if (!sort)
-    sortvar <- 1:k.all
+    sortvar <- seq_len(k.all)
+  #
+  if (!is.null(cid))
+    chknumeric(cid, length = 1)
+  #
+  if (!is.null(cid.below.null))
+    chknumeric(cid.below.null, length = 1)
+  #
+  if (!is.null(cid.above.null))
+    chknumeric(cid.above.null, length = 1)
+  #
+  avail.cid <- !is.null(cid) && !all(is.na(cid))
+  avail.cid.below.null <-
+    !is.null(cid.below.null) && !all(is.na(cid.below.null))
+  avail.cid.above.null <-
+    !is.null(cid.above.null) && !all(is.na(cid.above.null))
+  #
+  run_cidprop <- avail.cid | avail.cid.below.null | avail.cid.above.null
   
   
   ##
@@ -135,6 +207,7 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
   ## (3) Sort variables
   ##
   ##
+  
   o <- order(sortvar)
   ##
   n.e <- x$n.e[o]
@@ -161,7 +234,10 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
   ##
   TE <- x$TE[o]
   seTE <- x$seTE[o]
-  ##
+  #
+  incr.e <- x$incr.e[o]
+  incr.c <- x$incr.c[o]
+  #
   if (length(x$incr) > 1)
     incr <- x$incr[o]
   else if (!is.null(x$incr))
@@ -180,13 +256,11 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
   ##
   studlab <- x$studlab[o]
   slab <- character(k.all)
-  for (i in 1:k.all)
+  for (i in seq_len(k.all))
     slab[i] <- paste0("Adding ", studlab[i], " (k=", ncum[i], ")")
-  slab <- c(slab, "Pooled estimate")
-  studlab <- c(rev(rev(slab)[-1]), " ", rev(slab)[1])
   ##
   chknumeric(no, min = 1, length = 1)
-    ##
+  ##
   ## Select a single common effect or random effects models
   ##
   if (pooled == "common") {
@@ -215,6 +289,7 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
   x$lower.common <- x$lower.common[no.c]
   x$upper.common <- x$upper.common[no.c]
   x$zval.common <- x$zval.common[no.c]
+  x$text.common <- x$text.common[no.c]
   ##
   if (length(x$TE.random) == 1 &&
       length(x$TE.random) != length(x$seTE.random))
@@ -254,10 +329,11 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
   ## (4) Do sensitivity analysis
   ##
   ##
-  res.i <- matrix(NA, ncol = 21, nrow = k.all)
+  
+  res.i <- matrix(NA, ncol = 31, nrow = k.all)
   add.i <- matrix(NA, ncol = 3, nrow = k.all)
   ##
-  for (i in 1:k.all) {
+  for (i in seq_len(k.all)) {
     sel <- 1:i
     ##
     if (length(incr) > 1)
@@ -271,8 +347,8 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
                    exclude = exclude[sel],
                    ##
                    method = x$method, sm = x$sm,
-                   ##
-                   incr = incr.i, method.incr = x$method.incr,
+                   #
+                   incr.e = incr.e[sel], incr.c = incr.c[sel],
                    allstudies = x$allstudies, MH.exact = x$MH.exact,
                    RR.Cochrane = x$RR.Cochrane, Q.Cochrane = x$Q.Cochrane,
                    model.glmm =
@@ -284,7 +360,11 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
                    level.ma = x$level.ma,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
-                   ##
+                   #
+                   level.predict = x$level.predict,
+                   method.predict = x$method.predict,
+                   adhoc.hakn.pi = x$adhoc.hakn.pi,
+                   #
                    keepdata = FALSE,
                    warn = FALSE,
                    ##
@@ -305,7 +385,11 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
                     level.ma = x$level.ma,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
-                    ##
+                    #
+                    level.predict = x$level.predict,
+                    method.predict = x$method.predict,
+                    adhoc.hakn.pi = x$adhoc.hakn.pi,
+                    #
                     keepdata = FALSE,
                     warn = FALSE,
                     ##
@@ -324,7 +408,11 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
                    level.ma = x$level.ma,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
-                   ##
+                   #
+                   level.predict = x$level.predict,
+                   method.predict = x$method.predict,
+                   adhoc.hakn.pi = x$adhoc.hakn.pi,
+                   #
                    keepdata = FALSE,
                    ##
                    control = x$control)
@@ -342,7 +430,11 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
                    level.ma = x$level.ma,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
-                   ##
+                   #
+                   level.predict = x$level.predict,
+                   method.predict = x$method.predict,
+                   adhoc.hakn.pi = x$adhoc.hakn.pi,
+                   #
                    keepdata = FALSE,
                    warn = FALSE,
                    ##
@@ -355,7 +447,8 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
                    exclude = exclude[sel],
                    ##
                    method = x$method, sm = x$sm,
-                   incr = incr.i, method.incr = x$method.incr,
+                   #
+                   incr.e = incr.e[sel], incr.c = incr.c[sel],
                    model.glmm =
                      if (!is.null(x$model.glmm)) x$model.glmm else "UM.FS",
                    ##
@@ -365,7 +458,11 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
                    level.ma = x$level.ma,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
-                   ##
+                   #
+                   level.predict = x$level.predict,
+                   method.predict = x$method.predict,
+                   adhoc.hakn.pi = x$adhoc.hakn.pi,
+                   #
                    keepdata = FALSE,
                    warn = FALSE,
                    ##
@@ -384,7 +481,11 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
                     level.ma = x$level.ma,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
-                    ##
+                    #
+                    level.predict = x$level.predict,
+                    method.predict = x$method.predict,
+                    adhoc.hakn.pi = x$adhoc.hakn.pi,
+                    #
                     keepdata = FALSE,
                     warn = FALSE,
                     ##
@@ -406,7 +507,11 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
                     level.ma = x$level.ma,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
-                    ##
+                    #
+                    level.predict = x$level.predict,
+                    method.predict = x$method.predict,
+                    adhoc.hakn.pi = x$adhoc.hakn.pi,
+                    #
                     keepdata = FALSE,
                     warn = FALSE,
                     ##
@@ -427,7 +532,11 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
                     level.ma = x$level.ma,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
-                    ##
+                    #
+                    level.predict = x$level.predict,
+                    method.predict = x$method.predict,
+                    adhoc.hakn.pi = x$adhoc.hakn.pi,
+                    #
                     keepdata = FALSE,
                     warn = FALSE,
                     ##
@@ -448,100 +557,207 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
                       m$upper.common,                                #  4
                       m$statistic.common,                            #  5
                       m$pval.common,                                 #  6
+                      #
                       m$tau2,                                        #  7
                       m$lower.tau2,                                  #  8
                       m$upper.tau2,                                  #  9
                       m$se.tau2,                                     # 10
+                      #
                       m$tau,                                         # 11
                       m$lower.tau,                                   # 12
                       m$upper.tau,                                   # 13
+                      #
                       m$I2,                                          # 14
                       m$lower.I2,                                    # 15
                       m$upper.I2,                                    # 16
-                      sum(m$w.common, na.rm = TRUE),                 # 17
-                      if (sel.pft) 1 / mean(1 / n[sel]) else NA,     # 18
-                      NA,                                            # 19
+                      #
+                      m$Rb,                                          # 17
+                      #
+                      sum(m$w.common, na.rm = TRUE),                 # 18
+                      if (sel.pft) 1 / mean(1 / n[sel]) else NA,     # 19
                       if (sel.irft) 1 / mean(1 / time[sel]) else NA, # 20
-                      m$Rb                                           # 21
-                      )
+                      #
+                      NA,                                            # 21
+                      #
+                      NA,                                            # 22
+                      NA,                                            # 23
+                      NA,                                            # 24
+                      #
+                      m$k,                                           # 25
+                      m$k.study,                                     # 26
+                      m$k.all,                                       # 27
+                      m$k.TE,                                        # 28
+                      replaceNULL(m$k.MH),                           # 29
+                      NA,                                            # 30
+                      NA                                             # 31
+      )
     }
     ##
     else if (pooled == "random") {
+      if (run_cidprop) {
+        pp <-
+          cidprop(m,
+                   cid = cid,
+                   cid.below.null = cid.below.null,
+                   cid.above.null = cid.above.null,
+                   small.values = small.values)
+        #
+        prop.cid.below.null <- pp$prop.cid.below.null
+        prop.cid.above.null <- pp$prop.cid.above.null
+      }
+      else {
+        prop.cid.below.null <- NA
+        prop.cid.above.null <- NA
+      }
+      #
       res.i[i, ] <- c(m$TE.random,                                   #  1
                       m$seTE.random,                                 #  2
                       m$lower.random,                                #  3
                       m$upper.random,                                #  4
                       m$statistic.random,                            #  5
                       m$pval.random,                                 #  6
+                      #
                       m$tau2,                                        #  7
                       m$lower.tau2,                                  #  8
                       m$upper.tau2,                                  #  9
                       m$se.tau2,                                     # 10
+                      #
                       m$tau,                                         # 11
                       m$lower.tau,                                   # 12
                       m$upper.tau,                                   # 13
+                      #
                       m$I2,                                          # 14
                       m$lower.I2,                                    # 15
                       m$upper.I2,                                    # 16
-                      sum(m$w.random, na.rm = TRUE),                 # 17
-                      if (sel.pft) 1 / mean(1 / n[sel]) else NA,     # 18
-                      if (x$method.random.ci %in% c("HK", "KR"))     #
-                        m$df.random else NA,                         # 19
+                      #
+                      m$Rb,                                          # 17
+                      #
+                      sum(m$w.random, na.rm = TRUE),                 # 18
+                      if (sel.pft) 1 / mean(1 / n[sel]) else NA,     # 19
                       if (sel.irft) 1 / mean(1 / time[sel]) else NA, # 20
-                      m$Rb                                           # 21
-                      )
+                      #
+                      if (tdist_random) m$df.random else NA,         # 21
+                      #
+                      m$lower.predict,                               # 22
+                      m$upper.predict,                               # 23
+                      if (tdist_predict) m$df.predict else NA,       # 24
+                      #
+                      m$k,                                           # 25
+                      m$k.study,                                     # 26
+                      m$k.all,                                       # 27
+                      m$k.TE,                                        # 28
+                      replaceNULL(m$k.MH),                           # 29
+                      prop.cid.below.null,                           # 30
+                      prop.cid.above.null                            # 31
+      )
     }
   }
-  ##
+  #
   TE.i <- res.i[, 1]
   seTE.i <- res.i[, 2]
   lower.i <- res.i[, 3]
   upper.i <- res.i[, 4]
   statistic.i <- res.i[, 5]
   pval.i <- res.i[, 6]
-  ##
+  #
   tau2.i <- res.i[, 7]
   lower.tau2.i <- res.i[, 8]
   upper.tau2.i <- res.i[, 9]
   se.tau2.i <- res.i[, 10]
-  ##
+  #
   tau.i <- res.i[, 11]
   lower.tau.i <- res.i[, 12]
   upper.tau.i <- res.i[, 13]
-  ##
+  #
   I2.i <- res.i[, 14]
   lower.I2.i <- res.i[, 15]
   upper.I2.i <- res.i[, 16]
-  ##
-  weight.i <- res.i[, 17]
-  n.harmonic.mean.i <- res.i[, 18]
-  if (pooled == "random" & x$method.random.ci %in% c("HK", "KR"))
-    df.random.i <- res.i[, 19]
+  #
+  Rb.i <- res.i[, 17]
+  #
+  weight.i <- res.i[, 18]
+  n.harmonic.mean.i <- res.i[, 19]
   t.harmonic.mean.i <- res.i[, 20]
-  Rb.i <- res.i[, 21]
-  ##
-  method.tau.ci <- unique(add.i[, 1])
-  sign.lower.tau.i <- add.i[, 2]
-  sign.upper.tau.i <- add.i[, 3]
-  ##  
+  #
+  df.random.i <- res.i[, 21]
+  #
+  lower.predict.i <- res.i[, 22]
+  upper.predict.i <- res.i[, 23]
+  df.predict.i <- res.i[, 24]
+  #
+  k.i <- res.i[, 25]
+  k.study.i <- res.i[, 26]
+  k.all.i <- res.i[, 27]
+  k.TE.i <- res.i[, 28]
+  k.MH.i <- res.i[, 29]
+  #
+  prop.cid.below.null <- res.i[, 30]
+  prop.cid.above.null <- res.i[, 31]
+  #
+  method.tau.ci <- replaceNULL(unique(add.i[add.i[, 1] != "", 1]), "")
+  sign.lower.tau.i <- replaceNULL(unique(add.i[add.i[, 2] != "", 2]), "")
+  sign.upper.tau.i <- replaceNULL(unique(add.i[add.i[, 3] != "", 3]), "")
+  #
   if (pooled == "common") {
-    TE.s <- x$TE.common
-    seTE.s <- x$seTE.common
-    lower.TE.s <- x$lower.common
-    upper.TE.s <- x$upper.common
-    statistic.s <- x$statistic.common
-    pval.s <- x$pval.common
-    w.s <- sum(x$w.common, na.rm = TRUE)
+    TE.pooled <- x$TE.common
+    seTE.pooled <- x$seTE.common
+    lower.pooled <- x$lower.common
+    upper.pooled <- x$upper.common
+    statistic.pooled <- x$statistic.common
+    pval.pooled <- x$pval.common
+    w.pooled <- sum(x$w.common, na.rm = TRUE)
+    #
+    lower.predict.pooled <- NA
+    upper.predict.pooled <- NA
   }
-  ##
+  #
   else if (pooled == "random") {
-    TE.s <- x$TE.random
-    seTE.s <- x$seTE.random
-    lower.TE.s <- x$lower.random
-    upper.TE.s <- x$upper.random
-    statistic.s <- x$statistic.random
-    pval.s <- x$pval.random
-    w.s <- sum(x$w.random, na.rm = TRUE)
+    TE.pooled <- x$TE.random
+    seTE.pooled <- x$seTE.random
+    lower.pooled <- x$lower.random
+    upper.pooled <- x$upper.random
+    statistic.pooled <- x$statistic.random
+    pval.pooled <- x$pval.random
+    w.pooled <- sum(x$w.random, na.rm = TRUE)
+    #
+    lower.predict.pooled <- x$lower.predict
+    upper.predict.pooled <- x$upper.predict
+  }
+  #
+  df.random.pooled <- x$df.random
+  #
+  tau2.pooled <- x$tau2
+  se.tau2.pooled <- x$se.tau2
+  lower.tau2.pooled <- x$lower.tau2
+  upper.tau2.pooled <- x$upper.tau2
+  #
+  tau.pooled <- x$tau
+  lower.tau.pooled <- x$lower.tau
+  upper.tau.pooled <- x$upper.tau
+  #
+  I2.pooled <- x$I2
+  lower.I2.pooled <- x$lower.I2
+  upper.I2.pooled <- x$upper.I2
+  #
+  Rb.pooled <- x$Rb
+  #
+  n.harmonic.mean.pooled <- 1 / mean(1 / n)
+  t.harmonic.mean.pooled <- 1 / mean(1 / time)
+  #
+  if (pooled == "random" & run_cidprop) {
+    pp.pooled <-
+      cidprop(x,
+               cid = cid,
+               cid.below.null = cid.below.null,
+               cid.above.null = cid.above.null,
+               small.values = small.values)
+    #
+    prop.cid.below.null.pooled <- pp.pooled$prop.cid.below.null
+    prop.cid.above.null.pooled <- pp.pooled$prop.cid.above.null
+  }
+  else {
+    prop.cid.below.null.pooled <- NA
+    prop.cid.above.null.pooled <- NA
   }
   
   
@@ -550,84 +766,151 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
   ## (5) Generate R object
   ##
   ##
-  res <- list(studlab = studlab,
-              ##
+  
+  if (missing(text.pooled))
+    text.pooled <- if (pooled == "common") x$text.common else x$text.random
+  #
+  res <- list(studlab = slab,
+              #
+              TE = TE.i,
+              seTE = seTE.i,
+              df.random = df.random.i,
+              lower = lower.i,
+              upper = upper.i,
+              statistic = statistic.i,
+              pval = pval.i,
+              #
+              lower.predict = lower.predict.i,
+              upper.predict = upper.predict.i,
+              df.predict = df.predict.i,
+              #
+              w = weight.i,
+              #
+              tau2 = tau2.i,
+              se.tau2 = se.tau2.i,
+              lower.tau2 = lower.tau2.i,
+              upper.tau2 = upper.tau2.i,
+              #
+              tau = tau.i,
+              lower.tau = lower.tau.i,
+              upper.tau = upper.tau.i,
+              #
+              sign.lower.tau = sign.lower.tau.i,
+              sign.upper.tau = sign.upper.tau.i,
+              #
+              I2 = I2.i,
+              lower.I2 = lower.I2.i,
+              upper.I2 = upper.I2.i,
+              #
+              Rb = Rb.i,
+              #
+              n.harmonic.mean = n.harmonic.mean.i,
+              t.harmonic.mean = t.harmonic.mean.i,
+              #
+              k = k.i,
+              k.study = k.study.i,
+              k.all = k.all.i,
+              k.TE = k.TE.i,
+              k.MH = k.MH.i,
+              #
+              prop.cid.below.null = prop.cid.below.null,
+              prop.cid.above.null = prop.cid.above.null,
+              cid.below.null = cid.below.null,
+              cid.above.null = cid.above.null,
+              small.values = small.values,
+              #
               sm = x$sm,
               null.effect = x$null.effect,
-              ##
-              TE = c(TE.i, NA, TE.s),
-              seTE = c(seTE.i, NA, seTE.s),
-              statistic = c(statistic.i, NA, statistic.s),
-              pval = c(pval.i, NA, pval.s),
-              level = x$level.ma,
-              lower = c(lower.i, NA, lower.TE.s),
-              upper = c(upper.i, NA, upper.TE.s),
-              ##
-              three.level = x$three.level,
-              cluster = x$cluster, rho = x$rho,
-              ##
-              k = x$k, k.study = x$k.study, k.all = x$k.all, k.TE = x$k.TE,
-              ##
+              #
               pooled = pooled,
-              common = ifelse(pooled == "common", TRUE, FALSE),
-              random = ifelse(pooled == "random", TRUE, FALSE),
-              overall = TRUE,
-              overall.hetstat = TRUE,
-              prediction = FALSE,
+              common = pooled == "common",
+              random = pooled == "random",
+              overall = overall,
+              overall.hetstat = FALSE,
+              #
+              prediction = prediction,
               method.predict = x$method.predict,
+              adhoc.hakn.pi = x$adhoc.hakn.pi,
+              #
               backtransf = x$backtransf,
-              ##
+              func.backtransf = x$func.backtransf,
+              #
+              level = x$level.ma,
+              level.ma = x$level.ma,
+              level.predict = x$level.predict,
+              #
               method = x$method,
               method.random = x$method.random,
-              ##
-              w = c(weight.i, NA, w.s),
-              TE.common = NA, seTE.common = NA,
-              TE.random = NA, seTE.random = NA,
-              df.random =
-                if (pooled == "random" &
-                    x$method.random.ci %in% c("HK", "KR"))
-                  c(df.random.i, NA, x$df.random) else NULL,
-              level.ma = x$level.ma,
+              #
               method.random.ci = x$method.random.ci,
               adhoc.hakn.ci = x$adhoc.hakn.ci,
-              ##
-              Q = NA,
-              ##
+              #
               method.tau = x$method.tau,
-              method.tau.ci = method.tau.ci,
-              tau2 = c(tau2.i, NA, x$tau2),
-              se.tau2 = c(se.tau2.i, NA, x$se.tau2),
-              lower.tau2 = c(lower.tau2.i, NA, x$lower.tau2),
-              upper.tau2 = c(upper.tau2.i, NA, x$upper.tau2),
-              tau = c(tau.i, NA, x$tau),
-              lower.tau = c(lower.tau.i, NA, x$lower.tau),
-              upper.tau = c(upper.tau.i, NA, x$upper.tau),
+              method.tau.ci =
+                if (length(method.tau.ci) > 0) method.tau.ci else "",
+              #
               tau.preset = x$tau.preset,
               TE.tau = x$TE.tau,
-              sign.lower.tau.i = c(sign.lower.tau.i, NA, x$sign.lower.tau),
-              sign.upper.tau.i = c(sign.upper.tau.i, NA, x$sign.upper.tau),
               #
               method.I2 = x$method.I2,
               #
-              I2 = c(I2.i, NA, x$I2),
-              lower.I2 = c(lower.I2.i, NA, x$lower.I2),
-              upper.I2 = c(upper.I2.i, NA, x$upper.I2),
-              ##
-              Rb = c(Rb.i, NA, x$Rb),
-              ##
-              n.harmonic.mean = c(n.harmonic.mean.i, NA, 1 / mean(1 / n)),
-              t.harmonic.mean = c(t.harmonic.mean.i, NA, 1 / mean(1 / time)),
-              ##
+              k.pooled = x$k,
+              k.study.pooled = x$k.study,
+              k.all.pooled = x$k.all,
+              k.TE.pooled = x$k.TE,
+              k.MH.pooled = x$k.MH,
+              #
+              TE.pooled = TE.pooled,
+              seTE.pooled = seTE.pooled,
+              lower.pooled = lower.pooled,
+              upper.pooled = upper.pooled,
+              df.random.pooled = df.random.pooled,
+              statistic.pooled = statistic.pooled,
+              pval.pooled = pval.pooled,
+              w.pooled = w.pooled,
+              text.pooled = text.pooled,
+              #
+              lower.predict.pooled = lower.predict.pooled,
+              upper.predict.pooled = upper.predict.pooled,
+              df.predict.pooled = x$df.predict,
+              text.predict = x$text.predict,
+              #
+              prop.cid.below.null.pooled = prop.cid.below.null.pooled,
+              prop.cid.above.null.pooled = prop.cid.above.null.pooled,
+              #
+              Q.pooled = x$Q,
+              Q.Cochrane = x$Q.Cochrane,
+              #
+              tau2.pooled = tau2.pooled,
+              se.tau2.pooled = se.tau2.pooled,
+              lower.tau2.pooled = lower.tau2.pooled,
+              upper.tau2.pooled = upper.tau2.pooled,
+              #
+              tau.pooled = tau.pooled,
+              lower.tau.pooled = x$lower.tau,
+              upper.tau.pooled = upper.tau.pooled,
+              #
+              sign.lower.tau.pooled = x$sign.lower.tau,
+              sign.upper.tau.pooled = x$sign.upper.tau,
+              #
+              I2.pooled = I2.pooled,
+              lower.I2.pooled = lower.I2.pooled,
+              upper.I2.pooled = upper.I2.pooled,
+              #
+              Rb.pooled = Rb.pooled,
+              #
+              n.harmonic.mean.pooled = n.harmonic.mean.pooled,
+              t.harmonic.mean.pooled = t.harmonic.mean.pooled,
+              #
               pscale = x$pscale,
               irscale = x$irscale, irunit = x$irunit,
               #
               label.e = x$label.e,
               label.c = x$label.c,
               #
-              text.common = x$text.common, text.random = x$text.random,
-              text.predict = x$text.predict,
-              text.w.common = x$text.w.common, text.w.random = x$text.w.random,
-              ##
+              label.left = x$label.left,
+              label.right = x$label.right,
+              #
               title = x$title, complab = x$complab,
               outclab = x$outclab,
               ##
@@ -636,50 +919,46 @@ metacum.meta <- function(x, pooled, sortvar, no = 1, ...) {
               x = x,
               ##
               call = match.call())
-  
+  #
+  if (run_cidprop) {
+    res$cid.below.null <- pp$cid.below.null
+    res$cid.above.null <- pp$cid.above.null
+  }
+  else {
+    res$prop.cid.below.null <- NULL
+    res$prop.cid.above.null <- NULL
+    res$cid.below.null <- NULL
+    res$cid.above.null <- NULL
+    res$small.values <- NULL
+    #
+    res$prop.cid.below.null.pooled <- NULL
+    res$prop.cid.above.null.pooled <- NULL
+  }
+  #
   res$version <- packageDescription("meta")$Version
   ##
   res$x$common <- res$common
   res$x$random <- res$random
-  ##
-  ## Backward compatibility
-  ##
-  res$fixed <- res$x$fixed <- res$common
-  res$TE.fixed <- res$TE.common
-  res$seTE.fixed <- res$seTE.common
-  ##
-  res$text.fixed <- res$text.common
-  res$text.w.fixed <- res$text.w.common
-  
-  
-  class(res) <- c("metacum", "summary.meta", "meta")
-  ##
-  if (inherits(x, "trimfill"))
-    class(res) <- c(class(res), "trimfill")
-  
+  #
+  res$classes <- class(x)[class(x) != "meta"]
+  #
+  class(res) <- "metacum"
+  #
   res
 }
 
 
-
-
-
 #' @rdname metacum
 #' @export metacum
 
-
 metacum <- function(x, ...) 
   UseMethod("metacum")
 
 
-
-
-
 #' @rdname metacum
 #' @method metacum default
 #' @export
 
-
 metacum.default <- function(x, ...)
   stop("Cumulative meta-analysis not available for an object of class '",
        class(x)[1], "'.",
