@@ -73,6 +73,7 @@
 #'   between-study variance tau-squared.
 #' @param tau.common A logical indicating whether tau-squared should
 #'   be the same across subgroups.
+#' @param detail.tau Detail on between-study variance estimate.
 #' @param method.I2 A character string indicating which method is
 #'   used to estimate the heterogeneity statistic I\eqn{^2}. Either
 #'   \code{"Q"} or \code{"tau2"}, can be abbreviated
@@ -450,6 +451,7 @@ metamean <- function(n, mean, sd, studlab,
                      level.hetstat = gs("level.hetstat"),
                      tau.preset = NULL, TE.tau = NULL,
                      tau.common = gs("tau.common"),
+                     detail.tau = NULL,
                      #
                      method.I2 = gs("method.I2"),
                      #
@@ -1226,6 +1228,7 @@ metamean <- function(n, mean, sd, studlab,
                tau.preset = tau.preset,
                TE.tau = TE.tau,
                tau.common = FALSE,
+               detail.tau = detail.tau,
                #
                method.I2 = method.I2,
                #
@@ -1311,6 +1314,8 @@ metamean <- function(n, mean, sd, studlab,
   ##
   ## Add data
   ##
+  res$pairwise <- FALSE
+  #
   res$call <- match.call()
   ##
   if (keepdata) {
