@@ -468,6 +468,11 @@ settings.meta <- function(..., quietly = TRUE) {
     ##
     chkdeprecated(names.all, "method.incr", "addincr")
     chkdeprecated(names.all, "method.incr", "allincr")
+    #
+    chkdeprecated(names.all, "cid.below.null", "lower.equi")
+    chkdeprecated(names.all, "cid.above.null", "upper.equi")
+    chkdeprecated(names.all, "lty.cid", "lty.equi")
+    chkdeprecated(names.all, "col.cid", "col.equi")
   }
   
   
@@ -590,6 +595,7 @@ settings.meta <- function(..., quietly = TRUE) {
     setOption("zero.pval", TRUE)
     setOption("JAMA.pval", FALSE)
     setOption("digits.df", 4)
+    setOption("digits.cid", 4)
     ##
     setOption("details", TRUE)
     ##
@@ -676,12 +682,14 @@ settings.meta <- function(..., quietly = TRUE) {
     setOption("pooled.times", FALSE)
     setOption("study.results", TRUE)
     ##
-    setOption("lower.equi", NA)
-    setOption("upper.equi", NA)
-    setOption("lty.equi", 1)
-    setOption("col.equi", "blue")
-    setOption("fill.equi", "transparent")
+    setOption("cid", NA)
+    setOption("cid.below.null", NA)
+    setOption("cid.above.null", NA)
+    setOption("lty.cid", 1)
+    setOption("col.cid", "blue")
+    setOption("fill.cid", "transparent")
     setOption("fill", "transparent")
+    setOption("fill.equi", "transparent")
     ##
     setOption("leftcols", NULL)
     setOption("rightcols", NULL)
@@ -1081,6 +1089,9 @@ settings.meta <- function(..., quietly = TRUE) {
     catarg("method.bias        ")
     catarg("tool.rob           ")
     catarg("overall.hetstat    ")
+    catarg("cid                ")
+    catarg("cid.below.null          ")
+    catarg("cid.above.null          ")
     catarg("text.common        ")
     catarg("text.random        ")
     catarg("text.predict       ")
@@ -1118,6 +1129,7 @@ settings.meta <- function(..., quietly = TRUE) {
     catarg("zero.pval          ")
     catarg("JAMA.pval          ")
     catarg("digits.df          ")
+    catarg("digits.cid         ")
     catarg("details            ")
     catarg("print.tau2         ")
     catarg("print.tau2.ci      ")
@@ -1209,10 +1221,9 @@ settings.meta <- function(..., quietly = TRUE) {
     catarg("pooled.times           ")
     catarg("study.results          ")
     ##
-    catarg("lower.equi             ")
-    catarg("upper.equi             ")
-    catarg("lty.equi               ")
-    catarg("col.equi               ")
+    catarg("lty.cid                ")
+    catarg("col.cid                ")
+    catarg("fill.cid               ")
     catarg("fill.equi              ")
     ##
     catarg("fill                   ")
@@ -1343,22 +1354,14 @@ settings.meta <- function(..., quietly = TRUE) {
     ## General settings
     ##
     setlevel("level", args)
-    ##
-    na <- is.na(setlevel("level.ma", args))
-    depr <- setlevel("level.comb", args)
-    if (na & !is.na(depr))
-      setOption("level.ma", args[[depr]])
-    ##
-    na <- is.na(setlogical("common", args))
-    depr1 <- setlogical("comb.fixed", args)
-    depr2 <- setlogical("fixed", args)
-    if (na & !is.na(depr1))
-      setOption("common", args[[depr1]])
-    if (na & !is.na(depr2))
-      setOption("common", args[[depr2]])
-    ##      
-    setlogical("random", args)
-    ##
+    #
+    setOptionDepr(args, "level.ma", "level.comb", setlevel)
+    #
+    setOptionDepr(args, "common", "comb.fixed", setlogical)
+    setOptionDepr(args, "common", "fixed", setlogical)
+    #
+    setOptionDepr(args, "random", "comb.random", setlogical)
+    #
     na <- is.na(setcharacter("method.random.ci", args, gs("meth4random.ci")))
     depr <- setlogical("hakn", args)
     if (na & !is.na(depr)) {
@@ -1367,12 +1370,10 @@ settings.meta <- function(..., quietly = TRUE) {
       else
         setOption("method.random.ci", "classic")
     }
-    ##
-    na <- is.na(setcharacter("adhoc.hakn.ci", args, gs("adhoc4hakn.ci")))
-    depr <- setcharacter("adhoc.hakn", args, gs("adhoc4hakn.ci"))
-    if (na & !is.na(depr))
-      setOption("adhoc.hakn.ci", args[[depr]])
-    ##
+    #
+    setOptionDepr(args, "adhoc.hakn.ci", "adhoc.hakn", setcharacter,
+                  set = gs("adhoc4hakn.ci"))
+    #
     setcharacter("adhoc.hakn.pi", args, gs("adhoc4hakn.pi"))
     setcharacter("method.tau", args, gs("meth4tau"))
     setcharacter("method.tau.ci", args, c("J", "BJ", "QP", "PL", ""))
@@ -1396,17 +1397,11 @@ settings.meta <- function(..., quietly = TRUE) {
     setcharacter("CIseparator", args)
     setlogical("CIlower.blank", args)
     setlogical("CIupper.blank", args)
-    ##
-    na <- is.na(setlogical("print.subgroup.name", args))
-    depr <- setlogical("print.byvar", args)
-    if (na & !is.na(depr))
-      setOption("print.subgroup.name", args[[depr]])
-    ##    
-    na <- is.na(setcharacter("sep.subgroup", args))
-    depr <- setcharacter("byseparator", args)
-    if (na & !is.na(depr))
-      setOption("sep.subgroup", args[[depr]])
-    ##
+    #
+    setOptionDepr(args, "print.subgroup.name", "print.byvar", setlogical)
+    #
+    setOptionDepr(args, "sep.subgroup", "byseparator", setcharacter)
+    #
     setlogical("keepdata", args)
     setlogical("keeprma", args)
     setlogical("warn", args)
@@ -1416,12 +1411,9 @@ settings.meta <- function(..., quietly = TRUE) {
     setnumeric("digits.mean", args)
     setnumeric("digits.sd", args)
     setnumeric("digits.se", args)
-    ##
-    na <- is.na(setnumeric("digits.stat", args))
-    depr <- setnumeric("digits.zval", args)
-    if (na & !is.na(depr))
-      setOption("digits.stat", args[[depr]])
-    ##
+    #
+    setOptionDepr(args, "digits.stat", "digits.zval", setnumeric)
+    #
     setnumeric("digits.Q", args) 
     setnumeric("digits.tau2", args)
     setnumeric("digits.tau", args)
@@ -1436,6 +1428,7 @@ settings.meta <- function(..., quietly = TRUE) {
     setlogical("zero.pval", args)
     setlogical("JAMA.pval", args)
     setnumeric("digits.df", args)
+    setnumeric("digits.cid", args)
     ##
     setlogical("details", args)
     setlogical("print.tau2", args)
@@ -1453,6 +1446,14 @@ settings.meta <- function(..., quietly = TRUE) {
     setcharacter("text.Rb", args)
     ##
     setlogical("print.Q", args)
+    #
+    setnumeric("cid", args)
+    setOptionDepr(args, "cid.below.null", "lower.equi", setnumeric)
+    setOptionDepr(args, "cid.above.null", "upper.equi", setnumeric)
+    setOptionDepr(args, "lty.cid", "lty.equi", setnumeric)
+    setOptionDepr(args, "col.cid", "col.equi", setcolor)
+    setcolor("fill.cid", args)
+    setcolor("fill.equi", args)
     ##
     ## R function metabin
     ##
@@ -1540,12 +1541,6 @@ settings.meta <- function(..., quietly = TRUE) {
     setlogical("pooled.times", args)
     setlogical("study.results", args)
     ##
-    setnumeric("lower.equi", args)
-    setnumeric("upper.equi", args)
-    setnumeric("lty.equi", args)
-    setcolor("col.equi", args)
-    setcolor("fill.equi", args)
-    ##
     setcolor("fill", args)
     ##
     setcharacter("leftcols", args, length = 0,
