@@ -72,7 +72,21 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
     else
       seed.i <- NULL
     ##
-    if (bin)
+    if (bin) {
+      if (x$method.incr == "user") {
+        incr <- NULL
+        incr.e <- x$incr.e[sel]
+        incr.c <- x$incr.c[sel]
+      }
+      else {
+        incr <- x$incr
+        if (length(incr) > 1)
+          incr <- incr[sel]
+        #
+        incr.e <- NULL
+        incr.c <- NULL
+      }
+      #
       meta1 <- metabin(x$event.e[sel], x$n.e[sel],
                        x$event.c[sel], x$n.c[sel],
                        studlab = x$studlab[sel],
@@ -83,9 +97,11 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                        ##
                        method = x$method,
                        sm = x$sm,
-                       incr = if (length(x$incr) == 1) x$incr else x$incr[sel],
-                       method.incr = x$method.incr,
-                       allstudies = x$allstudies,
+                       #
+                       incr = incr,
+                       incr.e = incr.e, incr.c = incr.c,
+                       method.incr = x$method.incr, allstudies = x$allstudies,
+                       #
                        MH.exact = x$MH.exact,
                        RR.Cochrane = x$RR.Cochrane,
                        Q.Cochrane = x$Q.Cochrane,
@@ -109,7 +125,8 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                        keepdata = FALSE,
                        warn = x$warn,
                        control = x$control)
-    ##
+    }
+    #
     else if (cont)
       meta1 <- metacont(x$n.e[sel], x$mean.e[sel],
                         x$sd.e[sel],
@@ -230,7 +247,21 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                        warn = x$warn,
                        control = x$control)
     ##
-    else if (inc)
+    else if (inc) {
+      if (x$method.incr == "user") {
+        incr <- NULL
+        incr.e <- x$incr.e[sel]
+        incr.c <- x$incr.c[sel]
+      }
+      else {
+        incr <- x$incr
+        if (length(incr) > 1)
+          incr <- incr[sel]
+        #
+        incr.e <- NULL
+        incr.c <- NULL
+      }
+      #
       meta1 <- metainc(x$event.e[sel], x$time.e[sel],
                        x$event.c[sel], x$time.c[sel],
                        studlab = x$studlab[sel],
@@ -241,8 +272,11 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                        ##
                        method = x$method,
                        sm = x$sm,
-                       incr = if (length(x$incr) == 1) x$incr else x$incr[sel],
+                       #
+                       incr = incr,
+                       incr.e = incr.e, incr.c = incr.c,
                        method.incr = x$method.incr,
+                       #
                        model.glmm = x$model.glmm,
                        ##
                        level.ma = x$level.ma,
@@ -265,7 +299,8 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                        keepdata = FALSE,
                        warn = x$warn,
                        control = x$control)
-    ##
+    }
+    #
     else if (mean)
       meta1 <- metamean(x$n[sel], x$mean[sel], x$sd[sel],
                         studlab = x$studlab[sel],
@@ -425,8 +460,17 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                        Q = meta1$Q,
                        ##
                        tau2 = sum(meta1$tau2),
+                       lower.tau2 =
+                         if (meta1$three.level) NA else meta1$lower.tau2,
+                       upper.tau2 =
+                         if (meta1$three.level) NA else meta1$upper.tau2,
+                       #
                        tau = sum(meta1$tau),
-                       ##
+                       lower.tau =
+                         if (meta1$three.level) NA else meta1$lower.tau,
+                       upper.tau =
+                         if (meta1$three.level) NA else meta1$upper.tau,
+                       #
                        H = meta1$H,
                        lower.H = meta1$lower.H,
                        upper.H = meta1$upper.H,
@@ -500,8 +544,13 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
   Q.w <- extrVec(res.i, "Q", levs, TRUE)
   ##
   tau2.w <- extrVec(res.i, "tau2", levs)
+  lower.tau2.w <- extrVec(res.i, "lower.tau2", levs)
+  upper.tau2.w <- extrVec(res.i, "upper.tau2", levs)
+  #
   tau.w <- extrVec(res.i, "tau", levs)
-  ##
+  lower.tau.w <- extrVec(res.i, "lower.tau", levs)
+  upper.tau.w <- extrVec(res.i, "upper.tau", levs)
+  #
   H.w <- extrVec(res.i, "H", levs)
   lower.H.w <- extrVec(res.i, "lower.H", levs)
   upper.H.w <- extrVec(res.i, "upper.H", levs)
@@ -641,8 +690,17 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
     ## Heterogeneity measures
     ##
     tau2.w <- rep_len(sum(mlm[[1]]$sigma2), n.levs)
+    lower.tau2.w <- tau2.w
+    upper.tau2.w <- tau2.w
+    lower.tau2.w[!is.na(lower.tau2.w)] <- NA
+    upper.tau2.w[!is.na(upper.tau2.w)] <- NA
+    #
     tau.w <- sqrt(tau2.w)
-    ##
+    lower.tau.w <- tau.w
+    upper.tau.w <- tau.w
+    lower.tau.w[!is.na(lower.tau.w)] <- NA
+    upper.tau.w[!is.na(upper.tau.w)] <- NA
+    #
     upper.Rb.w <- lower.Rb.w <- Rb.w <- rep_len(NA, n.levs)
     ##
     ## Prediction interval
@@ -837,8 +895,17 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
     ## Heterogeneity measures
     ##
     tau2.w <- rep_len(glmm.r[[1]]$tau2, n.levs)
+    lower.tau2.w <- tau2.w
+    upper.tau2.w <- tau2.w
+    lower.tau2.w[!is.na(lower.tau2.w)] <- NA
+    upper.tau2.w[!is.na(upper.tau2.w)] <- NA
+    #
     tau.w <- sqrt(tau2.w)
-    ##
+    lower.tau.w <- tau.w
+    upper.tau.w <- tau.w
+    lower.tau.w[!is.na(lower.tau.w)] <- NA
+    upper.tau.w[!is.na(upper.tau.w)] <- NA
+    #
     upper.Rb.w <- lower.Rb.w <- Rb.w <- rep_len(NA, n.levs)
     ##
     ## Prediction interval
@@ -977,7 +1044,12 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
               pval.Q.w = pvalQ(Q.w, k.w - 1),
               ##
               tau2.w = tau2.w,
+              lower.tau2.w = lower.tau2.w,
+              upper.tau2.w = upper.tau2.w,
+              #
               tau.w = tau.w,
+              lower.tau.w = lower.tau.w,
+              upper.tau.w = upper.tau.w,
               ##
               H.w = H.w,
               lower.H.w = lower.H.w,
